@@ -20,7 +20,8 @@ class DashboardESDocument(ElasticsearchDocument):
                  url=None,  # type: Optional[str]
                  uri=None,  # type: Optional[str]
                  last_successful_run_timestamp=None,  # type: Optional[int]
-                 tags=None  # type: list
+                 tags=None,  # type: Optional[list[str]]
+                 badges=None,  # type: Optional[list[str]]
                  ):
         # type: (...) -> None
         self.group_name = group_name
@@ -36,3 +37,4 @@ class DashboardESDocument(ElasticsearchDocument):
         self.group_description = group_description
         self.query_names = query_names
         self.tags = tags
+        self.badges = badges
